@@ -43,7 +43,7 @@ EXTENSIONS = {
     'cr': {'text', 'crystal'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
-    'csproj': {'text', 'xml', 'csproj'},
+    'csproj': {'text', 'xml', 'csproj', 'msbuild'},
     'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
@@ -82,6 +82,7 @@ EXTENSIONS = {
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
     'fs': {'text', 'f#'},
+    'fsproj': {'text', 'xml', 'fsproj', 'msbuild'},
     'fsx': {'text', 'f#', 'f#script'},
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
@@ -120,6 +121,7 @@ EXTENSIONS = {
     'ino': {'text', 'ino', 'c++'},
     'inx': {'text', 'xml', 'inx'},
     'ipynb': {'text', 'jupyter', 'json'},
+    'ipp': {'text', 'c++'},
     'ixx': {'text', 'c++'},
     'j2': {'text', 'jinja'},
     'jade': {'text', 'jade'},
@@ -192,6 +194,7 @@ EXTENSIONS = {
     'php4': {'text', 'php'},
     'php5': {'text', 'php'},
     'phtml': {'text', 'php'},
+    'piskel': {'text', 'piskel', 'json'},
     'pl': {'text', 'perl'},
     'plantuml': {'text', 'plantuml'},
     'pm': {'text', 'perl'},
@@ -201,6 +204,7 @@ EXTENSIONS = {
     'pp': {'text', 'puppet'},
     'prisma': {'text', 'prisma'},
     'properties': {'text', 'java-properties'},
+    'props': {'text', 'xml', 'msbuild'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
     'psd1': {'text', 'powershell'},
@@ -212,7 +216,7 @@ EXTENSIONS = {
     'pxi': {'text', 'cython'},
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
-    'pyproj': {'text', 'xml', 'pyproj'},
+    'pyproj': {'text', 'xml', 'pyproj', 'msbuild'},
     'pyt': {'text', 'python'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
@@ -223,6 +227,7 @@ EXTENSIONS = {
     'rb': {'text', 'ruby'},
     'resx': {'text', 'resx', 'xml'},
     'rng': {'text', 'xml', 'relax-ng'},
+    'robot': {'text', 'robot'},
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
     's': {'text', 'asm'},
@@ -252,6 +257,7 @@ EXTENSIONS = {
     'swiftdeps': {'text', 'swiftdeps'},
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
+    'targets': {'text', 'xml', 'msbuild'},
     'templ': {'text', 'templ'},
     'tex': {'text', 'tex'},
     'textproto': {'text', 'textproto'},
@@ -261,6 +267,7 @@ EXTENSIONS = {
     'thrift': {'text', 'thrift'},
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
+    'tpp': {'text', 'c++'},
     'ts': {'text', 'ts'},
     'tsv': {'text', 'tsv'},
     'tsx': {'text', 'tsx'},
@@ -272,8 +279,8 @@ EXTENSIONS = {
     'urdf': {'text', 'xml', 'urdf'},
     'v': {'text', 'verilog'},
     'vb': {'text', 'vb'},
-    'vbproj': {'text', 'xml', 'vbproj'},
-    'vcxproj': {'text', 'xml', 'vcxproj'},
+    'vbproj': {'text', 'xml', 'vbproj', 'msbuild'},
+    'vcxproj': {'text', 'xml', 'vcxproj', 'msbuild'},
     'vdx': {'text', 'vdx'},
     'vh': {'text', 'verilog'},
     'vhd': {'text', 'vhdl'},
@@ -301,6 +308,7 @@ EXTENSIONS = {
     'xqy': {'text', 'xquery'},
     'xsd': {'text', 'xml', 'xsd'},
     'xsl': {'text', 'xml', 'xsl'},
+    'xslt': {'text', 'xml', 'xsl'},
     'yaml': {'text', 'yaml'},
     'yamlld': {'text', 'yaml', 'yamlld'},
     'yang': {'text', 'yang'},
@@ -352,6 +360,7 @@ NAMES = {
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
     '.salt-lint': EXTENSIONS['yaml'] | {'salt-lint'},
+    '.sqlfluff': EXTENSIONS['ini'],
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zlogin': EXTENSIONS['zsh'],
     '.zlogout': EXTENSIONS['zsh'],
@@ -383,14 +392,15 @@ NAMES = {
     'MAINTAINERS': EXTENSIONS['txt'],
     'Makefile': EXTENSIONS['mk'],
     'meson.build': EXTENSIONS['meson'],
-    'meson_options.txt': EXTENSIONS['meson'],
+    'meson.options': EXTENSIONS['meson'] | {'meson-options'},
+    'meson_options.txt': EXTENSIONS['meson'] | {'meson-options'},
     'makefile': EXTENSIONS['mk'],
     'NEWS': EXTENSIONS['txt'],
     'NOTICE': EXTENSIONS['txt'],
     'PATENTS': EXTENSIONS['txt'],
     'Pipfile': EXTENSIONS['toml'],
     'Pipfile.lock': EXTENSIONS['json'],
-    'PKGBUILD': {'text', 'bash', 'pkgbuild', 'alpm'},
+    'PKGBUILD': EXTENSIONS['bash'] | {'pkgbuild', 'alpm'},
     'poetry.lock': EXTENSIONS['toml'],
     'pom.xml': EXTENSIONS['pom'],
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
