@@ -170,7 +170,11 @@ def test_tags_from_path_plist_text(tmpdir):
         ('build.jenkins', {'text', 'groovy', 'jenkins'}),
         ('build.jenkinsfile', {'text', 'groovy', 'jenkins'}),
         ('meson.build', {'text', 'meson'}),
-        ('meson_options.txt', {'text', 'plain-text', 'meson'}),
+        ('meson.options', {'text', 'meson', 'meson-options'}),
+        (
+            'meson_options.txt',
+            {'text', 'plain-text', 'meson', 'meson-options'},
+        ),
         ('Vagrantfile', {'text', 'ruby'}),
         ('Tiltfile', {'text', 'tiltfile'}),
         ('Tiltfile.abc', {'text', 'tiltfile'}),
